// vincia27.cc is a part of the VINCIA event generator.
// Copyright (C) 2019 Peter Skands.
// VINCIA is licenced under the GNU GPL version 2, see COPYING for details.
// Please respect the MCnet Guidelines, see GUIDELINES for details.

// This is program to test pp > tt, eg to test massive IF antennae.

// 200 events (gg + qq > tt, fully leptonic)
// Pythia (no HAD)          9s
// Vincia (no QED, no HAD) 60s (so, slow, but still within factor 10)

#include "Pythia8/Vincia.h"
using namespace Pythia8;

int main() {

  //************************************************************************
  // Generator. LHC process and output selection. Initialization.
  Pythia pythia;
  VinciaPlugin vincia(&pythia);

  // Read user settings from file
  pythia.readFile("vincia27.cmnd");
  
  //************************************************************************  

  // Extract settings to be used in the main program.
  // Number of events, generated and listed ones.
  int nEvent = pythia.settings.mode("Main:numberOfEvents");
  int nAbort = pythia.settings.mode("Main:timesAllowErrors");
  bool vinciaOn = pythia.settings.flag("Vincia");  
  Event& event  = pythia.event;

  //************************************************************************  

  // Initialize
  if(!vincia.init()) { return EXIT_FAILURE; }

  //************************************************************************  
  
  // Histograms
  Hist hNFinal("nFinal",100,0.5,200.5);
    
  // Begin event loop. Generate event. Skip if error.
  int iAbort = 0;
  for (int iEvent = 0; iEvent < nEvent; ++iEvent) {
            
    bool aborted = !pythia.next();
    aborted = ( aborted || vincia.vinCom.doAbort()) ;    
    if (aborted){
      if (++iAbort < nAbort){
	vincia.vinCom.setAbort(false);
	continue;
      }
      cout << " Event generation aborted prematurely, owing to error!\n";
      cout<< "Event number was : "<<iEvent<<endl;
      break;
    }

    double nFinal = 0;
    for (int i=1; i<event.size(); ++i) {
      if (!event[i].isFinal()) continue;
      nFinal++;      
    }
    hNFinal.fill(nFinal);
    
  // End of event loop. Statistics. Histograms.
  }
  pythia.stat();
  if (vinciaOn) vincia.printInfo();
  
  cout<<hNFinal;
  
  // Done.
  return 0;
}
